@@ -15,8 +15,7 @@
 #     __init__.py
 #
 
-VERSION = '1.0'
-STATUS = 'beta'
-__doc__ = """PageBotCocoa module"""
-__version__ = '%s-%s' % (VERSION, STATUS)
+VERSION = '1.0.1.1'
+__doc__ = """PageBotOSX module"""
+__version__ = VERSION
 
